=======================
The ``lino-xl`` package
=======================





The **Lino Extensions Library** is a collection of plugins used by many Lino
applications.

- This repository is considered an integral part of the Lino framework, which is
  documented as a whole in the `Lino Book
  <https://www.lino-framework.org/about/overview.html>`__.

- Your feedback is welcome.  See https://community.lino-framework.org

- API changes to this repository are logged at
  https://www.lino-framework.org/changes/



